#filter emptyLines

#define MOZ_LANGPACK_CREATOR Kostas Papadimas

# If non-English locales wish to credit multiple contributors, uncomment this
# variable definition and use the format specified.
#define MOZ_LANGPACK_CONTRIBUTORS <em:contributor>Λούρδας Βασίλης</em:contributor> <em:contributor>Jim Spentzos</em:contributor>

#unfilter emptyLines
