#filter emptyLines

#define MOZ_LANGPACK_CREATOR mozilla.org

# If non-English locales wish to credit multiple contributors, uncomment this
# variable definition and use the format specified.
#define MOZ_LANGPACK_CONTRIBUTORS <em:contributor>Mark Tyndall</em:contributor> <em:contributor>Ian Neal</em:contributor>

#unfilter emptyLines
