#filter emptyLines

#define MOZ_LANGPACK_CREATOR El equipo de ChatZilla

#define MOZ_LANGPACK_HOMEPAGE http://chatzilla.hacksrus.com/

# If non-English locales wish to credit multiple contributors, uncomment this
# variable definition and use the format specified.
#define MOZ_LANGPACK_CONTRIBUTORS <em:contributor>Marcelo Poli</em:contributor> <em:contributor>Gabriela Montagu</em:contributor> <em:contributor>Pablo Lillia</em:contributor> <em:contributor>Sergio Celani</em:contributor> <em:contributor>Ariel Burone</em:contributor> <em:contributor>Mariano Cuenze</em:contributor> <em:contributor>Ramón Retamar</em:contributor> <em:contributor>Pamela Gulijczuk</em:contributor> <em:contributor>Guillermo Movia</em:contributor>

#unfilter emptyLines
