# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

#filter substitution

pref("general.useragent.locale", "@AB_CD@");

pref("intl.accept_languages", "ja");
pref("intl.charset.default", "UTF-8");
pref("intl.charset.detector", "ja_parallel_state_machine");
